==> dps-data-model-0.0.18-sources.jar: pl/topteam/dps/model/main_gen/DowodOsobisty.java <==
package pl.topteam.dps.model.main_gen;

import java.util.Date;
import pl.topteam.dps.generic.GenericDPSObject;

public abstract class DowodOsobisty extends GenericDPSObject {
    /**
     * DOWOD_OSOBISTY.ID
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private Long id;

    /**
     * DOWOD_OSOBISTY.OSOBA_ID
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private Long osobaId;

    /**
     * DOWOD_OSOBISTY.WYDANY_PRZEZ_ID
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private Long wydanyPrzezId;

    /**
     * DOWOD_OSOBISTY.DATA_WAZNOSCI
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private Date dataWaznosci;

    /**
     * DOWOD_OSOBISTY.DATA_WPROWADZENIA
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private Date dataWprowadzenia;

    /**
     * DOWOD_OSOBISTY.DATA_WYDANIA
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private Date dataWydania;

    /**
     * DOWOD_OSOBISTY.SERIA_NR
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private String seriaNr;

    /**
     * @mbggenerated 2014-03-10 10:45:37
     */
    private static final long serialVersionUID = 1L;

    /**
     * @return DOWOD_OSOBISTY.ID
     * @mbggenerated 2014-03-10 10:45:37
     */
    @Override
    public Long getId() {
        return id;
    }

    /**
     * DOWOD_OSOBISTY.ID
     *
     * @param id
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setId(Long id) {
        this.id = id;
    }

    /**
     * @return DOWOD_OSOBISTY.OSOBA_ID
     * @mbggenerated 2014-03-10 10:45:37
     */
    public Long getOsobaId() {
        return osobaId;
    }

    /**
     * DOWOD_OSOBISTY.OSOBA_ID
     *
     * @param osobaId
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setOsobaId(Long osobaId) {
        this.osobaId = osobaId;
    }

    /**
     * @return DOWOD_OSOBISTY.WYDANY_PRZEZ_ID
     * @mbggenerated 2014-03-10 10:45:37
     */
    public Long getWydanyPrzezId() {
        return wydanyPrzezId;
    }

    /**
     * DOWOD_OSOBISTY.WYDANY_PRZEZ_ID
     *
     * @param wydanyPrzezId
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setWydanyPrzezId(Long wydanyPrzezId) {
        this.wydanyPrzezId = wydanyPrzezId;
    }

    /**
     * @return DOWOD_OSOBISTY.DATA_WAZNOSCI
     * @mbggenerated 2014-03-10 10:45:37
     */
    public Date getDataWaznosci() {
        return dataWaznosci;
    }

    /**
     * DOWOD_OSOBISTY.DATA_WAZNOSCI
     *
     * @param dataWaznosci
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setDataWaznosci(Date dataWaznosci) {
        this.dataWaznosci = dataWaznosci;
    }

    /**
     * @return DOWOD_OSOBISTY.DATA_WPROWADZENIA
     * @mbggenerated 2014-03-10 10:45:37
     */
    public Date getDataWprowadzenia() {
        return dataWprowadzenia;
    }

    /**
     * DOWOD_OSOBISTY.DATA_WPROWADZENIA
     *
     * @param dataWprowadzenia
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setDataWprowadzenia(Date dataWprowadzenia) {
        this.dataWprowadzenia = dataWprowadzenia;
    }

    /**
     * @return DOWOD_OSOBISTY.DATA_WYDANIA
     * @mbggenerated 2014-03-10 10:45:37
     */
    public Date getDataWydania() {
        return dataWydania;
    }

    /**
     * DOWOD_OSOBISTY.DATA_WYDANIA
     *
     * @param dataWydania
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setDataWydania(Date dataWydania) {
        this.dataWydania = dataWydania;
    }

    /**
     * @return DOWOD_OSOBISTY.SERIA_NR
     * @mbggenerated 2014-03-10 10:45:37
     */
    public String getSeriaNr() {
        return seriaNr;
    }

    /**
     * DOWOD_OSOBISTY.SERIA_NR
     *
     * @param seriaNr
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setSeriaNr(String seriaNr) {
        this.seriaNr = seriaNr == null ? null : seriaNr.trim();
    }

    /**
     * @mbggenerated 2014-03-10 10:45:37
     */
    @Override
    public boolean equals(Object that) {
        if (this == that) {
            return true;
        }
        if (that == null) {
            return false;
        }
        if (getClass() != that.getClass()) {
            return false;
        }
        DowodOsobisty other = (DowodOsobisty) that;
        return (this.getId() == null ? other.getId() == null : this.getId().equals(other.getId()))
            && (this.getOsobaId() == null ? other.getOsobaId() == null : this.getOsobaId().equals(other.getOsobaId()))
            && (this.getWydanyPrzezId() == null ? other.getWydanyPrzezId() == null : this.getWydanyPrzezId().equals(other.getWydanyPrzezId()))
            && (this.getDataWaznosci() == null ? other.getDataWaznosci() == null : this.getDataWaznosci().equals(other.getDataWaznosci()))
            && (this.getDataWprowadzenia() == null ? other.getDataWprowadzenia() == null : this.getDataWprowadzenia().equals(other.getDataWprowadzenia()))
            && (this.getDataWydania() == null ? other.getDataWydania() == null : this.getDataWydania().equals(other.getDataWydania()))
            && (this.getSeriaNr() == null ? other.getSeriaNr() == null : this.getSeriaNr().equals(other.getSeriaNr()));
    }

    /**
     * @mbggenerated 2014-03-10 10:45:37
     */
    @Override
    public int hashCode() {
        final int prime = 31;
        int result = 1;
        result = prime * result + ((getId() == null) ? 0 : getId().hashCode());
        result = prime * result + ((getOsobaId() == null) ? 0 : getOsobaId().hashCode());
        result = prime * result + ((getWydanyPrzezId() == null) ? 0 : getWydanyPrzezId().hashCode());
        result = prime * result + ((getDataWaznosci() == null) ? 0 : getDataWaznosci().hashCode());
        result = prime * result + ((getDataWprowadzenia() == null) ? 0 : getDataWprowadzenia().hashCode());
        result = prime * result + ((getDataWydania() == null) ? 0 : getDataWydania().hashCode());
        result = prime * result + ((getSeriaNr() == null) ? 0 : getSeriaNr().hashCode());
        return result;
    }

    /**
     * @mbggenerated 2014-03-10 10:45:37
     */
    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append(getClass().getSimpleName());
        sb.append(" [");
        sb.append("Hash = ").append(hashCode());
        sb.append(", id=").append(id);
        sb.append(", osobaId=").append(osobaId);
        sb.append(", wydanyPrzezId=").append(wydanyPrzezId);
        sb.append(", dataWaznosci=").append(dataWaznosci);
        sb.append(", dataWprowadzenia=").append(dataWprowadzenia);
        sb.append(", dataWydania=").append(dataWydania);
        sb.append(", seriaNr=").append(seriaNr);
        sb.append("]");
        return sb.toString();
    }
}

==> dps-data-model-0.0.23-sources.jar: pl/topteam/dps/model/main_gen/DowodOsobisty.java <==
package pl.topteam.dps.model.main_gen;

import java.util.Date;
import pl.topteam.dps.model.main_gen.GenericDPSObject;

public abstract class DowodOsobisty extends GenericDPSObject {
    /**
     * DOWOD_OSOBISTY.ID
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private Long id;

    /**
     * DOWOD_OSOBISTY.OSOBA_ID
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private Long osobaId;

    /**
     * DOWOD_OSOBISTY.WYDANY_PRZEZ_ID
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private Long wydanyPrzezId;

    /**
     * DOWOD_OSOBISTY.DATA_WAZNOSCI
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private Date dataWaznosci;

    /**
     * DOWOD_OSOBISTY.DATA_WPROWADZENIA
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private Date dataWprowadzenia;

    /**
     * DOWOD_OSOBISTY.DATA_WYDANIA
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private Date dataWydania;

    /**
     * DOWOD_OSOBISTY.SERIA_NR
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private String seriaNr;

    /**
     * @mbggenerated 2014-03-13 16:02:38
     */
    private static final long serialVersionUID = 1L;

    /**
     * @return DOWOD_OSOBISTY.ID
     * @mbggenerated 2014-03-13 16:02:38
     */
    @Override
    public Long getId() {
        return id;
    }

    /**
     * DOWOD_OSOBISTY.ID
     *
     * @param id
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setId(Long id) {
        this.id = id;
    }

    /**
     * @return DOWOD_OSOBISTY.OSOBA_ID
     * @mbggenerated 2014-03-13 16:02:38
     */
    public Long getOsobaId() {
        return osobaId;
    }

    /**
     * DOWOD_OSOBISTY.OSOBA_ID
     *
     * @param osobaId
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setOsobaId(Long osobaId) {
        this.osobaId = osobaId;
    }

    /**
     * @return DOWOD_OSOBISTY.WYDANY_PRZEZ_ID
     * @mbggenerated 2014-03-13 16:02:38
     */
    public Long getWydanyPrzezId() {
        return wydanyPrzezId;
    }

    /**
     * DOWOD_OSOBISTY.WYDANY_PRZEZ_ID
     *
     * @param wydanyPrzezId
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setWydanyPrzezId(Long wydanyPrzezId) {
        this.wydanyPrzezId = wydanyPrzezId;
    }

    /**
     * @return DOWOD_OSOBISTY.DATA_WAZNOSCI
     * @mbggenerated 2014-03-13 16:02:38
     */
    public Date getDataWaznosci() {
        return dataWaznosci;
    }

    /**
     * DOWOD_OSOBISTY.DATA_WAZNOSCI
     *
     * @param dataWaznosci
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setDataWaznosci(Date dataWaznosci) {
        this.dataWaznosci = dataWaznosci;
    }

    /**
     * @return DOWOD_OSOBISTY.DATA_WPROWADZENIA
     * @mbggenerated 2014-03-13 16:02:38
     */
    public Date getDataWprowadzenia() {
        return dataWprowadzenia;
    }

    /**
     * DOWOD_OSOBISTY.DATA_WPROWADZENIA
     *
     * @param dataWprowadzenia
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setDataWprowadzenia(Date dataWprowadzenia) {
        this.dataWprowadzenia = dataWprowadzenia;
    }

    /**
     * @return DOWOD_OSOBISTY.DATA_WYDANIA
     * @mbggenerated 2014-03-13 16:02:38
     */
    public Date getDataWydania() {
        return dataWydania;
    }

    /**
     * DOWOD_OSOBISTY.DATA_WYDANIA
     *
     * @param dataWydania
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setDataWydania(Date dataWydania) {
        this.dataWydania = dataWydania;
    }

    /**
     * @return DOWOD_OSOBISTY.SERIA_NR
     * @mbggenerated 2014-03-13 16:02:38
     */
    public String getSeriaNr() {
        return seriaNr;
    }

    /**
     * DOWOD_OSOBISTY.SERIA_NR
     *
     * @param seriaNr
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setSeriaNr(String seriaNr) {
        this.seriaNr = seriaNr == null ? null : seriaNr.trim();
    }

    /**
     * @mbggenerated 2014-03-13 16:02:38
     */
    @Override
    public boolean equals(Object that) {
        if (this == that) {
            return true;
        }
        if (that == null) {
            return false;
        }
        if (getClass() != that.getClass()) {
            return false;
        }
        DowodOsobisty other = (DowodOsobisty) that;
        return (this.getId() == null ? other.getId() == null : this.getId().equals(other.getId()))
            && (this.getOsobaId() == null ? other.getOsobaId() == null : this.getOsobaId().equals(other.getOsobaId()))
            && (this.getWydanyPrzezId() == null ? other.getWydanyPrzezId() == null : this.getWydanyPrzezId().equals(other.getWydanyPrzezId()))
            && (this.getDataWaznosci() == null ? other.getDataWaznosci() == null : this.getDataWaznosci().equals(other.getDataWaznosci()))
            && (this.getDataWprowadzenia() == null ? other.getDataWprowadzenia() == null : this.getDataWprowadzenia().equals(other.getDataWprowadzenia()))
            && (this.getDataWydania() == null ? other.getDataWydania() == null : this.getDataWydania().equals(other.getDataWydania()))
            && (this.getSeriaNr() == null ? other.getSeriaNr() == null : this.getSeriaNr().equals(other.getSeriaNr()));
    }

    /**
     * @mbggenerated 2014-03-13 16:02:38
     */
    @Override
    public int hashCode() {
        final int prime = 31;
        int result = 1;
        result = prime * result + ((getId() == null) ? 0 : getId().hashCode());
        result = prime * result + ((getOsobaId() == null) ? 0 : getOsobaId().hashCode());
        result = prime * result + ((getWydanyPrzezId() == null) ? 0 : getWydanyPrzezId().hashCode());
        result = prime * result + ((getDataWaznosci() == null) ? 0 : getDataWaznosci().hashCode());
        result = prime * result + ((getDataWprowadzenia() == null) ? 0 : getDataWprowadzenia().hashCode());
        result = prime * result + ((getDataWydania() == null) ? 0 : getDataWydania().hashCode());
        result = prime * result + ((getSeriaNr() == null) ? 0 : getSeriaNr().hashCode());
        return result;
    }

    /**
     * @mbggenerated 2014-03-13 16:02:38
     */
    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append(getClass().getSimpleName());
        sb.append(" [");
        sb.append("Hash = ").append(hashCode());
        sb.append(", id=").append(id);
        sb.append(", osobaId=").append(osobaId);
        sb.append(", wydanyPrzezId=").append(wydanyPrzezId);
        sb.append(", dataWaznosci=").append(dataWaznosci);
        sb.append(", dataWprowadzenia=").append(dataWprowadzenia);
        sb.append(", dataWydania=").append(dataWydania);
        sb.append(", seriaNr=").append(seriaNr);
        sb.append("]");
        return sb.toString();
    }
}
